@@ -29,6 +29,9 @@ data/images/micro/Makefile \
 data/images/micro/Makefile.in \
 data/images/nuvoX/Makefile \
 data/images/nuvoX/Makefile.in \
+data/themes/Makefile \
+data/themes/Makefile.in \
+data/themes/*.edj \
 include/config.h \
 include/config.h.in \
 include/stamp-h1 \
