@@ -294,113 +294,7 @@ gchar* ascifyStyle(const gchar c) {
     gchar *ret = NULL;
     
     switch ( (guchar)c ) {
-        case 0x41: /* LATIN CAPITAL LETTER A */
-        case 0x61: /* LATIN SMALL LETTER A */
-            ret = g_strdup("a");
-            break;
-        case 0x42: /* LATIN CAPITAL LETTER B */
-        case 0x62: /* LATIN SMALL LETTER B */
-            ret = g_strdup("b");
-            break;
-        case 0x43: /* LATIN CAPITAL LETTER C */
-        case 0x63: /* LATIN SMALL LETTER C */
-            ret = g_strdup("c");
-            break;
-        case 0x44: /* LATIN CAPITAL LETTER D */
-        case 0x64: /* LATIN SMALL LETTER D */
-            ret = g_strdup("d");
-            break;
-        case 0x45: /* LATIN CAPITAL LETTER E */
-        case 0x65: /* LATIN SMALL LETTER E */
-            ret = g_strdup("e");
-            break;
-        case 0x46: /* LATIN CAPITAL LETTER F */
-        case 0x66: /* LATIN SMALL LETTER F */
-            ret = g_strdup("f");
-            break;
-        case 0x47: /* LATIN CAPITAL LETTER G */
-        case 0x67: /* LATIN SMALL LETTER G */
-            ret = g_strdup("g");
-            break;
-        case 0x48: /* LATIN CAPITAL LETTER H */
-        case 0x68: /* LATIN SMALL LETTER H */
-            ret = g_strdup("h");
-            break;
-        case 0x49: /* LATIN CAPITAL LETTER I */
-        case 0x69: /* LATIN SMALL LETTER I */
-            ret = g_strdup("i");
-            break;
-        case 0x4a: /* LATIN CAPITAL LETTER J */
-        case 0x6a: /* LATIN SMALL LETTER J */
-            ret = g_strdup("j");
-            break;
-        case 0x4b: /* LATIN CAPITAL LETTER K */
-        case 0x6b: /* LATIN SMALL LETTER K */
-            ret = g_strdup("k");
-            break;
-        case 0x4c: /* LATIN CAPITAL LETTER L */
-        case 0x6c: /* LATIN SMALL LETTER L */
-            ret = g_strdup("l");
-            break;
-        case 0x4d: /* LATIN CAPITAL LETTER M */
-        case 0x6d: /* LATIN SMALL LETTER M */
-            ret = g_strdup("m");
-            break;
-        case 0x4e: /* LATIN CAPITAL LETTER N */
-        case 0x6e: /* LATIN SMALL LETTER N */
-            ret = g_strdup("n");
-            break;
-        case 0x4f: /* LATIN CAPITAL LETTER O */
-        case 0x6f: /* LATIN SMALL LETTER O */
-            ret = g_strdup("o");
-            break;
-        case 0x50: /* LATIN CAPITAL LETTER P */
-        case 0x70: /* LATIN SMALL LETTER P */
-            ret = g_strdup("p");
-            break;
-        case 0x51: /* LATIN CAPITAL LETTER Q */
-        case 0x71: /* LATIN SMALL LETTER Q */
-            ret = g_strdup("q");
-            break;
-        case 0x52: /* LATIN CAPITAL LETTER R */
-        case 0x72: /* LATIN SMALL LETTER R */
-            ret = g_strdup("r");
-            break;
-        case 0x53: /* LATIN CAPITAL LETTER S */
-        case 0x73: /* LATIN SMALL LETTER S */
-            ret = g_strdup("s");
-            break;
-        case 0x54: /* LATIN CAPITAL LETTER T */
-        case 0x74: /* LATIN SMALL LETTER T */
-            ret = g_strdup("t");
-            break;
-        case 0x55: /* LATIN CAPITAL LETTER U */
-        case 0x75: /* LATIN SMALL LETTER U */
-            ret = g_strdup("u");
-            break;
-        case 0x56: /* LATIN CAPITAL LETTER V */
-        case 0x76: /* LATIN SMALL LETTER V */
-            ret = g_strdup("v");
-            break;
-        case 0x57: /* LATIN CAPITAL LETTER W */
-        case 0x77: /* LATIN SMALL LETTER W */
-            ret = g_strdup("w");
-            break;
-        case 0x58: /* LATIN CAPITAL LETTER X */
-        case 0x78: /* LATIN SMALL LETTER X */
-            ret = g_strdup("x");
-            break;
-        case 0x59: /* LATIN CAPITAL LETTER Y */
-        case 0x79: /* LATIN SMALL LETTER Y */
-            ret = g_strdup("y");
-            break;
-        case 0x5a: /* LATIN CAPITAL LETTER Z */
-        case 0x7a: /* LATIN SMALL LETTER Z */
-            ret = g_strdup("z");
-            break;
-        case 0xC3:
-            c3 = TRUE;
-            break;
+        
         case 0x80: /* LATIN CAPITAL LETTER A WITH GRAVE */
         case 0x81: /* LATIN CAPITAL LETTER A WITH ACUTE */
         case 0x82: /* LATIN CAPITAL LETTER A WITH CIRCUMFLEX */
@@ -413,30 +307,18 @@ gchar* ascifyStyle(const gchar c) {
         case 0xa3: /* LATIN SMALL LETTER A WITH TILDE */
         case 0xa4: /* LATIN SMALL LETTER A WITH DIAERESIS */
         case 0xa5: /* LATIN SMALL LETTER A WITH RING ABOVE */
-            //g_debug("Special letter");
-            if (c3) {
-                c3 = FALSE;
-                ret = g_strdup("a");
-                //g_debug("\t from C3 %X to %s", (guchar)c, ret);
-            }
+            ret = g_strdup("a");
+            //g_debug("\t from C3 %X to %s", (guchar)c, ret);
             break;
         case 0x86: /* LATIN CAPITAL LETTER AE */
         case 0xa6: /* LATIN SMALL LETTER AE */
-            //g_debug("Special letter");
-            if (c3) {
-                c3 = FALSE;
-                ret = g_strdup("ae");
-                //g_debug("\t from C3 %X to %s", (guchar)c, ret);
-            }
+            ret = g_strdup("ae");
+            //g_debug("\t from C3 %X to %s", (guchar)c, ret);
             break;
         case 0x87: /* LATIN CAPITAL LETTER C WITH CEDILLA */
         case 0xa7: /* LATIN SMALL LETTER C WITH CEDILLA */
-            //g_debug("Special letter");
-            if (c3) {
-                c3 = FALSE;
-                ret = g_strdup("c");
-                //g_debug("\t from C3 %X to %s", (guchar)c, ret);
-            }
+            ret = g_strdup("c");
+            //g_debug("\t from C3 %X to %s", (guchar)c, ret);
             break;
         case 0x88: /* LATIN CAPITAL LETTER E WITH GRAVE */
         case 0x89: /* LATIN CAPITAL LETTER E WITH ACUTE */
@@ -445,12 +327,8 @@ gchar* ascifyStyle(const gchar c) {
         case 0xa9: /* LATIN SMALL LETTER E WITH ACUTE */
         case 0xaa: /* LATIN SMALL LETTER E WITH CIRCUMFLEX */
         case 0xab: /* LATIN SMALL LETTER E WITH DIAERESIS */
-            //g_debug("Special letter");
-            if (c3) {
-                c3 = FALSE;
-                ret = g_strdup("e");
-                //g_debug("\t from C3 %X to %s", (guchar)c, ret);
-            }
+            ret = g_strdup("e");
+            //g_debug("\t from C3 %X to %s", (guchar)c, ret);
             break;
         case 0x8c: /* LATIN CAPITAL LETTER I WITH GRAVE */
         case 0x8d: /* LATIN CAPITAL LETTER I WITH ACUTE */
@@ -460,30 +338,18 @@ gchar* ascifyStyle(const gchar c) {
         case 0xad: /* LATIN SMALL LETTER I WITH ACUTE */
         case 0xae: /* LATIN SMALL LETTER I WITH CIRCUMFLEX */
         case 0xaf: /* LATIN SMALL LETTER I WITH DIAERESIS */
-            //g_debug("Special letter");
-            if (c3) {
-                c3 = FALSE;
-                ret = g_strdup("i");
-                //g_debug("\t from C3 %X to %s", (guchar)c, ret);
-            }
+            ret = g_strdup("i");
+            //g_debug("\t from C3 %X to %s", (guchar)c, ret);
             break;
         case 0x90: /* LATIN CAPITAL LETTER ETH */
         case 0xb0: /* LATIN SMALL LETTER ETH */
-            //g_debug("Special letter");
-            if (c3) {
-                c3 = FALSE;
-                ret = g_strdup("d");
-                //g_debug("\t from C3 %X to %s", (guchar)c, ret);
-            }
+            ret = g_strdup("d");
+            //g_debug("\t from C3 %X to %s", (guchar)c, ret);
             break;
         case 0x91: /* LATIN CAPITAL LETTER N WITH TILDE */
         case 0xb1: /* LATIN SMALL LETTER N WITH TILDE */
-            //g_debug("Special letter");
-            if (c3) {
-                c3 = FALSE;
-                ret = g_strdup("n");
-                //g_debug("\t from C3 %X to %s", (guchar)c, ret);
-            }
+            ret = g_strdup("n");
+            //g_debug("\t from C3 %X to %s", (guchar)c, ret);
             break;
         case 0x92: /* LATIN CAPITAL LETTER O WITH GRAVE */
         case 0x93: /* LATIN CAPITAL LETTER O WITH ACUTE */
@@ -497,12 +363,8 @@ gchar* ascifyStyle(const gchar c) {
         case 0xb5: /* LATIN SMALL LETTER O WITH TILDE */
         case 0xb6: /* LATIN SMALL LETTER O WITH DIAERESIS */
         case 0xb8: /* LATIN SMALL LETTER O WITH STROKE */
-            //g_debug("Special letter");
-            if (c3) {
-                c3 = FALSE;
-                ret = g_strdup("o");
-                //g_debug("\t from C3 %X to %s", (guchar)c, ret);
-            }
+            ret = g_strdup("o");
+            //g_debug("\t from C3 %X to %s", (guchar)c, ret);
             break;
         case 0x99: /* LATIN CAPITAL LETTER U WITH GRAVE */
         case 0x9a: /* LATIN CAPITAL LETTER U WITH ACUTE */
@@ -512,45 +374,26 @@ gchar* ascifyStyle(const gchar c) {
         case 0xba: /* LATIN SMALL LETTER U WITH ACUTE */
         case 0xbb: /* LATIN SMALL LETTER U WITH CIRCUMFLEX */
         case 0xbc: /* LATIN SMALL LETTER U WITH DIAERESIS */
-            //g_debug("Special letter");
-            if (c3) {
-                c3 = FALSE;
-                ret = g_strdup("u");
-                //g_debug("\t from C3 %X to %s", (guchar)c, ret);
-            }
+            ret = g_strdup("u");
+            //g_debug("\t from C3 %X to %s", (guchar)c, ret);
             break;
         case 0x9d: /* LATIN CAPITAL LETTER Y WITH ACUTE */
         case 0xbd: /* LATIN SMALL LETTER Y WITH ACUTE */
         case 0xbf: /* LATIN SMALL LETTER Y WITH DIAERESIS */
-            //g_debug("Special letter");
-            if (c3) {
-                c3 = FALSE;
-                ret = g_strdup("y");
-                //g_debug("\t from C3 %X to %s", (guchar)c, ret);
-            }
+            ret = g_strdup("y");
+            //g_debug("\t from C3 %X to %s", (guchar)c, ret);
             break;
         case 0x9e: /* LATIN CAPITAL LETTER THORN */
         case 0xbe: /* LATIN SMALL LETTER THORN */
-            //g_debug("Special letter");
-            if (c3) {
-                c3 = FALSE;
-                ret = g_strdup("th");
-                //g_debug("\t from C3 %X to %s", (guchar)c, ret);
-            }
+            ret = g_strdup("th");
+            //g_debug("\t from C3 %X to %s", (guchar)c, ret);
             break;
         case 0x9f: /* LATIN SMALL LETTER SHARP S */
-            //g_debug("Special letter");
-            if (c3) {
-                c3 = FALSE;
-                ret = g_strdup("s");
-                //g_debug("\t from C3 %X to %s", (guchar)c, ret);
-            }
-            break;
-        case 0x20: /* SPACE */
-            ret = g_strdup(" ");
+            ret = g_strdup("s");
+            //g_debug("\t from C3 %X to %s", (guchar)c, ret);
             break;
         default:
-            //g_debug("Ignored letter %X", c);
+            g_message("Ignored letter %X", c);
             break;
     }
     return ret;
@@ -562,37 +405,42 @@ gchar* ascifyStyle(const gchar c) {
  * 
  * @param source Source string
  * 
- * @return String stripped
+ * @return String stripped or NULL if the word doesn't contain diatrics
  */
 gchar* strip(gchar* source) {
     //g_debug("-> %s %s()", __FILE__, __FUNCTION__);
     gchar *result = NULL;
+    gchar *tmp = NULL;
     gint i = 0;
     gint sourceLenght = 0;
+    gchar c;
+    gchar *converted;
     
     //g_debug("Stripping %s", source);
     
     sourceLenght = strlen(source);
-
-    if ( sourceLenght != 0 ) {
-
-        // Allocate space, worst case
-        result = malloc( sourceLenght * 2 );
-
-        if( result == NULL ) {
-          g_error( "Insufficient memory available\n" );
-          
-        } else {
-            result[0] = '\0';
-            for( i = 0; i < sourceLenght; i++) {
-                gchar c = source[i];
-                gchar *converted = ascifyStyle(c);
-                if ( converted != NULL ) {
-                    result = g_strconcat( result, converted, NULL );
-                }
+    
+    for( i = 0; i < sourceLenght; i++) {
+        c = source[i];
+        if ( ((guchar)c) == 0xC3 ) {
+            
+            // Ignore the current c (equals to 0xC3)
+            tmp = strndup(source, i);
+            
+            // Conver the special character
+            c = source[++i];
+            converted = ascifyStyle(c);
+            
+            if ( converted != NULL ) {
+                result = g_strconcat( tmp, converted, NULL );
+            } else {
+                result = g_strconcat( result, &source[i], NULL );
             }
+            g_free(converted);
+            g_free(tmp);
         }
     }
+    
     return result;
 }
 
