@@ -22,6 +22,7 @@
 #include "estardict-engine.h"
 #include "estardict-engine-strip.h"
 
+
 // IFO
 const guint IFO_FILE_MAX_LENGHT_LINE = 100;
 const gchar* IFO_FILE_FIRST_LINE = "StarDict's dict ifo file";
@@ -317,7 +318,11 @@ gboolean loadIdx(StarDictInfo* starDictInfo) {
         return FALSE;
     }
 
-    // Open the dict file for reading
+    /* Open the dict file for reading
+     * If path refers to an uncompressed file, and mode refers to a read mode, 
+     * gzopen() shall attempt to open the file and return a gzFile object suitable 
+     * for reading directly from the file without any decompression.
+     */
     starDictInfo->dictFile = gzopen(starDictInfo->dictFileName, "rb9");
 
     // If we can open the file
@@ -503,108 +508,18 @@ char* retrieveDefinition(StarDictInfo* starDictInfo, WordCoordinates* coordinate
 }
 
 
-/**
- * @brief Really simple untag method.
- * For converting from html to text.
- * No check for invalid tag format, no replace for HTML special
- * characters
- *
- * @param html HTML string
- * @return Text string
- */
-gchar* untag(gchar* html) {
-    int i;
-    int j;
-    gboolean insideTag = FALSE;
-    gchar c;
-
-    gchar* text = g_try_malloc(strlen(html));
-    if ( text == NULL) {
-        g_critical("Error allocating memory for the untag method");
-        estardictEngineError = ESTARDICT_ENGINE_ERROR_MEMORY_ERROR_DEFINITION;
-        return NULL;
-    }
-
-    for (i = 0, j = 0; i < strlen(html); i++ ) {
-        c = html[i];
-
-        if ( c == '<') {
-            insideTag = TRUE;
-        }
-
-        if ( !insideTag ) {
-            text[j] = c;
-            j++;
-        }
-
-        if ( c == '>') {
-            insideTag = FALSE;
-        }
-    }
-    text[j] = '\0';
-
-    g_debug("HTML %s", html);
-    g_debug("TEXT %s", text);
-
-    return text;
-}
-
-
-/**
- * @brief Parse the text from the dict file and returns the formatted
- * definition.
- *
- * @param starDictInfo Dictionary
- * @param dictText Definition text from dict file
- * @return Formatted definition
- */
-gchar* parseDefinition(StarDictInfo* starDictInfo, gchar* dictText) {
-    g_debug("-> %s %s()", __FILE__, __FUNCTION__);
-
-    gchar* sametypesequence = starDictInfo->sametypesequence;
-
-    // Single sametypesequence pure text
-    if (
-        sametypesequence != NULL &&
-        strlen(sametypesequence) == 1 &&
-        (g_ascii_strcasecmp(sametypesequence, "m") == 0 ||
-        g_ascii_strcasecmp(sametypesequence, "l") == 0 ||
-        g_ascii_strcasecmp(sametypesequence, "t") == 0 ||
-        g_ascii_strcasecmp(sametypesequence, "y") == 0)
-    ) {
-        g_message("---> Sametypesequence pure text");
-        return dictText + '\0';
-
-    // Single sametypesequence HTML and pango
-    } else if (
-        sametypesequence != NULL &&
-        strlen(sametypesequence) == 1 &&
-        (
-        g_ascii_strcasecmp(sametypesequence, "h") == 0 ||
-        g_ascii_strcasecmp(sametypesequence, "g") == 0
-        )
-    ) {
-        return untag(dictText + '\0');
-    } else {
-        estardictEngineError = ESTARDICT_ENGINE_ERROR_PARSING_DEFINITION;
-    }
-
-    return NULL;
-}
-
-
 /**
  * @brief Return the coordinates in the data file for the given word and
  * dictionary.
+ * Case sensitive function.
  *
  * @param starDictInfo Dictionary
  * @param word Word to search
- * @param diatrics Consider diatrics when search
  * @return Coordinates for the given word and dictionary, NULL if not
  * found or in case of error (in this case the estardictEngineError
  * is valued)
  */
-WordCoordinates* getWordCoordinates(StarDictInfo* starDictInfo, gchar* word, gboolean diacritics) {
+WordCoordinates* getWordCoordinates(StarDictInfo* starDictInfo, gchar* word) {
     g_debug("-> %s %s()", __FILE__, __FUNCTION__);
 
     WordCoordinates* coordinates = NULL;
@@ -620,7 +535,6 @@ WordCoordinates* getWordCoordinates(StarDictInfo* starDictInfo, gchar* word, gbo
             gchar buffer[COORDINATES_BUFFER_LENGTH + 1];
 
             gchar* tmp = NULL;
-            gchar* tmp1 = NULL;
             guint len = 0;
             guint wordLenght = strlen(word);
             gboolean continueRead = FALSE;
@@ -650,22 +564,8 @@ WordCoordinates* getWordCoordinates(StarDictInfo* starDictInfo, gchar* word, gbo
                 // Loop over buffer size
                 while (pos < min) {
 
-                    // Normalize the word without diatrics
-                    // e.g. espátula
-                    if (diacritics) {
-                        tmp1 = strip(tmp);
-                        //g_debug("Search stripped word %s", tmp1);
-                    }
-
                     // we have found word in dictionary
-                    if ( 
-                     ( strlen(tmp) == wordLenght && g_ascii_strncasecmp(tmp, word, wordLenght) == 0 )
-                     || ( diacritics && tmp1 != NULL && strlen(tmp1) == wordLenght && g_ascii_strncasecmp(tmp1, word, wordLenght) == 0 )
-                    ) {
-                        
-                        if ( diacritics ) {
-                            word = g_strdup(tmp);
-                        }
+                    if ( strlen(tmp) == wordLenght && strncmp(tmp, word, wordLenght) == 0 ) {
 
                         // Ignore the first word inside the loop cycle
                         // it could be partial
@@ -738,11 +638,12 @@ WordCoordinates* getWordCoordinates(StarDictInfo* starDictInfo, gchar* word, gbo
                 firstCycle = FALSE;
 
             } while(continueRead);
-
+            
         } else {
             g_critical("--->Cannot open idx file");
             estardictEngineError = ESTARDICT_ENGINE_ERROR_OPEN_IDX;
         }
+        
     } else {
         g_critical("--->Internal error while opening idx file");
     }
@@ -752,6 +653,7 @@ WordCoordinates* getWordCoordinates(StarDictInfo* starDictInfo, gchar* word, gbo
 
 /**
  * @brief Return the word list with the given prefix and dictionary.
+ * Case insensitive function and it looks also for diatrics word.
  *
  * @param starDictInfo Dictionary
  * @param prefix Prefix to search
@@ -764,120 +666,147 @@ GArray* getWordList(StarDictInfo* starDictInfo, gchar* prefix, gint maxNumSugges
     g_debug("-> %s %s()", __FILE__, __FUNCTION__);
 
     GArray* wordList = g_array_sized_new(TRUE, TRUE, sizeof(gchar*), maxNumSuggestedWords);
+    
+    if ( starDictInfo != NULL && starDictInfo->idxFile != NULL ) {
 
-    rewind(starDictInfo->idxFile);
+        rewind(starDictInfo->idxFile);
 
-    // If we can open the file
-    if (starDictInfo->idxFile) {
+        // If we can open the file
+        if (starDictInfo->idxFile) {
 
-        // Copy a piece of the file content in the buffer
-        gchar buffer[COORDINATES_BUFFER_LENGTH + 1];
+            // Copy a piece of the file content in the buffer
+            gchar buffer[COORDINATES_BUFFER_LENGTH + 1];
 
-        gchar* tmp = NULL;
-        guint len = 0;
-        guint prefixLenght = strlen(prefix);
-        gboolean continueRead = FALSE;
-        gboolean firstCycle = TRUE;
+            gchar* tmp = NULL;
+            gchar* tmp1 = NULL;
+            guint len = 0;
+            guint prefixLenght = strlen(prefix);
+            gboolean continueRead = FALSE;
+            gboolean firstCycle = TRUE;
 
-        do {
+            do {
 
-            gint readed = (gint)fread(buffer, sizeof(gchar), COORDINATES_BUFFER_LENGTH, starDictInfo->idxFile);
+                gint readed = (gint)fread(buffer, sizeof(gchar), COORDINATES_BUFFER_LENGTH, starDictInfo->idxFile);
 
-            if (readed < 0) {
-                g_critical("---> Error while reading file for searching");
-                estardictEngineError = ESTARDICT_ENGINE_ERROR_READING_IDX;
-                break;
-
-            }
-
-            continueRead = (readed == (COORDINATES_BUFFER_LENGTH));
-
-            tmp = buffer;
-
-            guint pos = 0;
-
-            // I want to be sure to have the words after the given prefix
-            gint min = _MIN(readed, COORDINATES_BUFFER_LENGTH - (maxNumSuggestedWords * COORDINATES_BLOCK) );
-
-            // Loop over buffer size
-            while (pos < min) {
-                gint i;
-
-                // we have found a word that start with prefix in the dictionary
-                if ( g_ascii_strncasecmp(tmp, prefix, prefixLenght) == 0 ) {
-
-                    // Ignore the first word inside the loop cycle
-                    // it could be partial
-                    if ( !firstCycle && pos < COORDINATES_BLOCK ) {
-
-                        // calculate length of word
-                        len = strlen(tmp) + 1;
-
-                        // go to the coordinate field (offset, size)
-                        tmp += len;
-
-                        // go to the next word
-                        tmp += 2 * sizeof(guint);
-
-                        // update position value
-                        pos = pos + len + 2 * sizeof(guint);
-
-                        continue;
-                    }
-
-                    for (i = 0; i < maxNumSuggestedWords; i++) {
-
-                        // New word
-                        gchar* newWord = g_strdup(tmp);
-
-                        // Add to the word list
-                        g_array_append_val(wordList, newWord);
-
-                        // calculate length of word
-                        len = strlen(tmp) + 1;
-
-                        // go to the coordinate field (offset, size)
-                        tmp += len;
-
-                        // go to the next word
-                        tmp += 2 * sizeof(guint);
-                    }
-
-                    continueRead = FALSE;
+                if (readed < 0) {
+                    g_critical("---> Error while reading file for searching");
+                    estardictEngineError = ESTARDICT_ENGINE_ERROR_READING_IDX;
                     break;
+
                 }
 
-                // calculate length of word
-                len = strlen(tmp) + 1;
+                continueRead = (readed == (COORDINATES_BUFFER_LENGTH));
 
-                // go to the coordinate field (offset, size)
-                tmp += len;
+                tmp = buffer;
 
-                // go to the next word
-                tmp += 2 * sizeof(guint);
+                guint pos = 0;
 
-                // update position value
-                pos = pos + len + 2 * sizeof(guint);
-            }
+                // I want to be sure to have the words after the given prefix
+                gint min = _MIN(readed, COORDINATES_BUFFER_LENGTH - (maxNumSuggestedWords * COORDINATES_BLOCK) );
 
+                // Loop over buffer size
+                while (pos < min) {
+                    gint i;
+                    
+                    // Normalize the word without diatrics
+                    // e.g. espátula
+                    //g_debug("Search NO stripped word %s", tmp);
+                    tmp1 = strip(tmp);
+                    //g_debug("Search stripped word %s", tmp1);
 
+                    
+                    // we have found a word that start with prefix in the dictionary
+                    if ( 
+                        g_ascii_strncasecmp(tmp, prefix, prefixLenght) == 0 
+                       || ( tmp1 != NULL && g_ascii_strncasecmp(tmp1, prefix, prefixLenght) == 0 )
+                    ) {
+                        
+                        // Ignore the first word inside the loop cycle
+                        // it could be partial
+                        if ( !firstCycle && pos < COORDINATES_BLOCK ) {
 
-            if (!continueRead) break;
+                            // calculate length of word
+                            len = strlen(tmp) + 1;
 
-            // Create some overlap to be sure to not miss words
-            gint result = fseek(starDictInfo->idxFile, COORDINATES_BLOCK * (-2), SEEK_CUR);
-            if ( result != 0 ) {
-                g_critical("--->Cannot seek idx file");
-                estardictEngineError = ESTARDICT_ENGINE_ERROR_READING_IDX;
-            }
+                            // go to the coordinate field (offset, size)
+                            tmp += len;
 
-            firstCycle = FALSE;
+                            // go to the next word
+                            tmp += 2 * sizeof(guint);
 
-        } while(continueRead);
+                            // update position value
+                            pos = pos + len + 2 * sizeof(guint);
 
-    } else {
-        g_critical("--->Cannot open idx file");
-        estardictEngineError = ESTARDICT_ENGINE_ERROR_OPEN_IDX;
+                            continue;
+                        }
+
+                        // Normalize the word without diatrics for following words
+                        tmp1 = strip(tmp);
+                        for (
+                            i = 0; 
+                            i < maxNumSuggestedWords 
+                            && (
+                                g_ascii_strncasecmp(tmp, prefix, prefixLenght) == 0 
+                                || ( tmp1 != NULL && g_ascii_strncasecmp(tmp1, prefix, prefixLenght) == 0 )
+                            );
+                            i++
+                        ) {
+                            
+                            // New word
+                            gchar* newWord = g_strdup(tmp);
+
+                            // Add to the word list
+                            g_array_append_val(wordList, newWord);
+
+                            // calculate length of word
+                            len = strlen(tmp) + 1;
+
+                            // go to the coordinate field (offset, size)
+                            tmp += len;
+
+                            // go to the next word
+                            tmp += 2 * sizeof(guint);
+                            
+                            // Normalize the word without diatrics for following words
+                            tmp1 = strip(tmp);
+                        }
+
+                        continueRead = FALSE;
+                        break;
+                    }
+
+                    // calculate length of word
+                    len = strlen(tmp) + 1;
+
+                    // go to the coordinate field (offset, size)
+                    tmp += len;
+
+                    // go to the next word
+                    tmp += 2 * sizeof(guint);
+
+                    // update position value
+                    pos = pos + len + 2 * sizeof(guint);
+                    
+                    g_free(tmp1);
+                }
+
+                if (!continueRead) break;
+
+                // Create some overlap to be sure to not miss words
+                gint result = fseek(starDictInfo->idxFile, COORDINATES_BLOCK * (-2 * maxNumSuggestedWords), SEEK_CUR);
+                if ( result != 0 ) {
+                    g_critical("--->Cannot seek idx file");
+                    estardictEngineError = ESTARDICT_ENGINE_ERROR_READING_IDX;
+                }
+
+                firstCycle = FALSE;
+
+            } while(continueRead);
+            
+        } else {
+            g_critical("--->Cannot open idx file");
+            estardictEngineError = ESTARDICT_ENGINE_ERROR_OPEN_IDX;
+        }
     }
 
     return wordList;
@@ -900,33 +829,22 @@ char* getDefinition(StarDictInfo* starDictInfo, gchar* word) {
     g_assert(word != NULL);
     g_debug("%s %s", starDictInfo->bookname, word);
 
-    char* definition = NULL;
+    gchar* definition = NULL;
     WordCoordinates* coordinates = NULL;
 
-    coordinates = getWordCoordinates(starDictInfo, word, FALSE);
-
-    if ( coordinates == NULL
-        && estardictEngineError != ESTARDICT_ENGINE_ERROR_READING_IDX 
-        && estardictEngineError != ESTARDICT_ENGINE_ERROR_OPEN_IDX
-        && isPlainLetters(word) ) {
-            coordinates = getWordCoordinates(starDictInfo, word, TRUE);
-    }
+    coordinates = getWordCoordinates(starDictInfo, word);
 
     // Word found
     if ( coordinates != NULL ) {
         g_debug("%s: %ld, %ld", word, coordinates->offset, coordinates->size );
 
         // Text from dict file
-        char* dictText = retrieveDefinition(starDictInfo, coordinates);
+        definition = retrieveDefinition(starDictInfo, coordinates);
 
         // Free coordinates
         g_free(coordinates);
         coordinates = NULL;
 
-        if (dictText != NULL) {
-            definition = parseDefinition(starDictInfo, dictText);
-        }
-
     // Word not found
     } else {
         if ( estardictEngineError != ESTARDICT_ENGINE_ERROR_READING_IDX && estardictEngineError != ESTARDICT_ENGINE_ERROR_OPEN_IDX )
