@@ -27,6 +27,7 @@
 #include "estardict-gui-utils.h"
 #include "estardict-config.h"
 #include "../engine/estardict-engine.h"
+#include "../engine/estardict-engine-parsing.h"
 #include <time.h>
 #include <stdio.h>
 #include <errno.h>
@@ -35,6 +36,7 @@
 
 // Dictionaries information
 Eina_List *starDictionariesInfo;
+gint maxNumberSuggestedWordsPerDictionary;
 
 /**
  * @brief Destroy
@@ -269,23 +271,22 @@ static void newSoundDictionarySelect(void *data, Evas_Object *obj, void *event_i
 
     if (selected) {
 
-        // If it is a directory
-        if ( selected[strlen(selected)-1] == '/' ) {
-            soundDictionaryPath =  g_strdup(selected);
-            gchar* soundDictionaryName = getNameFromPath(soundDictionaryPath);
-            setSoundDictionaryEntry(truncateWord(soundDictionaryName));
+        // It is a directory, check made by the UI
+        g_debug("directory selected %s", selected);
+        soundDictionaryPath =  g_strdup(selected);
+        gchar* soundDictionaryName = getNameFromPath(soundDictionaryPath);
+        setSoundDictionaryEntry(truncateWord(soundDictionaryName));
 
-            g_message("soundDictionaryPath %s", soundDictionaryPath);
+        g_message("soundDictionaryPath %s", soundDictionaryPath);
 
-            saveSoundDictionary(soundDictionaryPath);
+        saveSoundDictionary(soundDictionaryPath);
 
-            // In any case delete the parent window
-            evas_object_del(data);
+        // In any case delete the parent window
+        evas_object_del(data);
 
-        } else {
-            g_message("You have to select a dictionary. The directory should contain folders a, b, c and so on");
-            createDialog( (Evas_Object *)data, addSpaces(DIALOG_SELECT_SOUND_DICTIONARY) );
-        }
+        // Add a check
+        //g_message("You have to select a dictionary. The directory should contain folders a, b, c and so on");
+        //createDialog( (Evas_Object *)data, addSpaces(DIALOG_SELECT_SOUND_DICTIONARY) );
     } else {
 
         // In any case delete the parent window
@@ -401,12 +402,12 @@ void showSuggestedWords(void *data, Evas_Object *obj, void *event_info) {
                     GArray* list = NULL;
                     guint i = 0;
 
-                    list = getWordList(starDictInfo, word, MAX_NUMBER_SUGGESTED_WORDS);
+                    list = getWordList(starDictInfo, word, maxNumberSuggestedWordsPerDictionary);
 
                     for ( i = 0; i < list->len; i++) {
                         gchar* word = g_array_index(list, gchar*, i);
                         addSuggestedWord(word);
-                        //g_debug("Current item is %s", word);
+                        //g_message("Current item is %s", word);
                         g_free(word);
                     }
                     g_array_free(list, TRUE);
@@ -455,7 +456,7 @@ void speak(void *data, Evas_Object *obj, void *event_info) {
         // Speak
         word = trimwhitespace(word);
         // Use sprinf instead of g_strconcat because word[0] is a char
-        sprintf(filename, "%s%c/%s.wav", soundDictionaryPath, word[0], word);
+        sprintf(filename, "%s/%c/%s.wav", soundDictionaryPath, word[0], word);
         g_debug("--> File name %s", filename);
 
         // If file exists
@@ -588,10 +589,14 @@ void searchWord(void *data, Evas_Object *obj, void *event_info) {
     gchar* dictionanyName = NULL;
     gboolean wordFound = FALSE;
     gboolean definitionErrorFlag = FALSE;
+    gchar* formattedDefinition = NULL;
+    gchar* word = NULL;
+    gchar* definition = NULL;
+    gchar* parsedDefinition = NULL;
        
     hideSuggestedWordBox();
 
-    gchar* word = g_strdup(elm_entry_entry_get(data));
+    word = elm_entry_markup_to_utf8(elm_entry_entry_get(data));
 
     if ( word != NULL && strlen(word)>0 ) {
         clearDefinition();
@@ -602,19 +607,30 @@ void searchWord(void *data, Evas_Object *obj, void *event_info) {
             EINA_LIST_FOREACH(starDictionariesInfo, l, starDictInfo) {
 				
                 if ( starDictInfo != NULL ) {
-                    gchar* definition = getDefinition(starDictInfo, trimwhitespace(word));
+                    definition = getDefinition(starDictInfo, trimwhitespace(word));
 
                     if ( definition != NULL ) {
                         wordFound = TRUE;
-                        gchar* formattedDefinition = formatDefinition(definition);
-                                  
+                        
+                        // Parse the definition using the stardict encoding value (for example h means html)
+                        parsedDefinition = parseDefinition(starDictInfo, definition);                        
+                        g_free(definition);
+                        
+                        // Format the definition for the UI
+                        formattedDefinition = formatDefinition(parsedDefinition);                      
+                        g_free(parsedDefinition);
+                         
                         // Get dictionary name
                         if ( starDictInfo->bookname != NULL ) {
                             dictionanyName = truncateWord(starDictInfo->bookname);
                         } else {
                             g_message("Dictionary bookname not set");
                         }
+                         
                         setDefinition(dictionanyName, formattedDefinition);
+                        g_free(formattedDefinition);                         
+                        
+                        
                     } else {
                         definitionErrorFlag = checkForEngineDefinitionError();
                     }
@@ -824,6 +840,10 @@ void initializeDictionaries() {
     if ( eina_list_count( dictionaries ) == 1 && empty ) {
         setTipsOnStartup();
     }
+    
+    if ( eina_list_count( dictionaries ) != 0 ) {
+        maxNumberSuggestedWordsPerDictionary = MAX_NUMBER_SUGGESTED_WORDS / eina_list_count( dictionaries );
+    }
 }
 
 
@@ -847,7 +867,7 @@ void saveDictionaries(void *data, Evas_Object *obj, void *event_info) {
     g_message("Save dictionaries in the configuration file");
     if ( setDictionaries(dictionaries) ) {
         initializeDictionaries();
-    }       
+    }
        
     promoteDefinitionPage();
 }
