@@ -45,7 +45,10 @@ Evas_Object *win;
 #define WIDTH_GTA 33
 #define WIDTH_N900 33
 
-#define ROOT_DIR "/usr/share/estardict/"
+#define VERSION_SIZE 1024
+#define DESCRIPTION_LENGHT 4096
+
+#define ROOT_DIR "/opt/estardict/"
 
 #define DICTIONARIES_FRAME_LABEL i18n("Dictionaries")
 #define ADD_BUTTON_LABEL i18n("Add")
@@ -76,6 +79,16 @@ The main target is the openmoko Freerunner cellphone and secondly the netbook.\
 * Supports dictionaries in StarDict formats.\
 <br>\
 * Voice capability\
+<br>\
+* <font color=\"#0000FF\">C</font>\
+<font color=\"#001188\">o</font>\
+<font color=\"#0011CC\">l</font>\
+<font color=\"#47A199\">o</font>\
+<font color=\"#47A1FF\">r</font>\
+<font color=\"#F14B77\">e</font>\
+<font color=\"#F14BCC\">d</font>\
+ html supported.\
+<br><br>\
 ")
 
 #define TIPS_ON_STARTUP i18n("\
@@ -112,6 +125,8 @@ First icon on the left.\
 #define SCALE_LABEL i18n("Scale")
 #define TIMES_LABEL i18n("Times")
 
+#define DEFAULT_THEME "%s/theme/default.edj"
+
 #define DICTIONARIES_ICON "%s/images/crystalClear/dictionaries.png"
 #define SETTINGS_ICON "%s/images/micro/settings.png"
 #define SPEAKER_ICON "%s/images/crystalClear/speaker.png"
